@@ -114,16 +114,15 @@ class RcData:
         res = []
         tree = ET.parse(self._path)
         root = tree.getroot()
-        for child in root:
-            if child.tag != 'qresource':
-                debug_print("child.tag != 'qresource'", child.tag)
+        for qresource in root:
+            if qresource.tag != 'qresource':
+                debug_print("qresource.tag != 'qresource'", qresource.tag)
                 continue
-            for child_ in child:
-                if child_.tag != 'file':
-                    debug_print("child_.tag != 'file'", child_.tag)
+            for file in qresource:
+                if file.tag != 'file':
+                    debug_print("file.tag != 'file'", file.tag)
                     continue
-                #debug_print("child_.text", child_.text)
-                path = os.path.join(os.path.dirname(self._path), os.path.normpath(child_.text))
+                path = os.path.join(os.path.dirname(self._path), os.path.normpath(file.text))
                 res.append(path)
         return res
     
@@ -199,6 +198,10 @@ class Schedule(eventloop.Schedule):
         self._collection = collection
 
     def append(self, task, timeout):
+        if isinstance(task, list):
+            for item in task:
+                self.append(item, timeout)
+            return
         ext = os.path.splitext(task)[1]
         if ext not in ['.qrc','.ui']:
             rc = self._collection.find(task)
